0.7.1 (2018-10-13)
------------------
- Add URL to related pypi page [#28]
- Make singledispatch an optional dependency for < python 3.4. Thanks [GhostofGoes].
- URLField bug [#20]
- Deprecation warnings fixed for python 3.7 [#27]


0.6.2 (2018-02-12)
----------------
- Contribution [GabrielDav]: TimeField and DateTimeField fields.


0.6.1 (2018-01-31)
----------------
- Strict Mode [Issue #8] throws an exception when receiving an undefined key.


0.3 (2017-06-23)
----------------
- New type: ImmutableDict
- Add function on TypedMapping
- Bug fixes in from_yaml and from_json functions.


0.2 (2017-06-05)
----------------
- Allow None by default in Typed Collections.


0.1 (2017-05-24)
----------------
- Initial release.
